# safir-logging

safir-logging is a subpackage of Safir, Rubin Observatory's library for building [FastAPI](https://fastapi.tiangolo.com/) services for the [Rubin Science Platform (Phalanx)](https://github.com/lsst-sqre/phalanx) and [Roundtable](https://github.com/lsst-sqre/roundtable) Kubernetes clusters.
It is a separate PyPI module so that it can be used as a dependency in contexts where the full Safir dependency is undesirable.

safir-logging is available from [PyPI](https://pypi.org/project/safir-logging/):

```sh
pip install safir-logging
```

safir-logging is developed and tested in conjunction with Safir.
Read more about Safir at https://safir.lsst.io.
